#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""Test device server"""

import sys
import time
import numpy
import thread

from PyTango import AttrQuality, AttrWriteType, DispLevel, DevState, DebugIt
from PyTango.server import Device, DeviceMeta, attribute, command, run
from PyTango.server import device_property
import PyTango

class TestDevice(Device):
    __metaclass__ = DeviceMeta

    trignumber = attribute(label="Trig Number", dtype=float,
                        display_level=DispLevel.OPERATOR,
                        access=AttrWriteType.READ,
                        doc="the number of trig already generated")
    
    def init_device(self):
        Device.init_device(self)
        self.trig_number = 0
        self.set_state(DevState.ON)

        self.set_change_event("trignumber",True, False)      
        self.poll_command('Trig',1000)

        attrRAW = PyTango.ImageAttr("mod", PyTango.ArgType.DevDouble, PyTango.AttrWriteType.READ,1000,1000)
        self.add_attribute(attrRAW)
        self.set_change_event("mod", True, False)
    
    def read_trignumber(self):
        return self.trig_number
    
    @command
    def Trig(self):
        # turn on the actual power supply here
        self.trig_number += 1
        self.push_change_event("trignumber",self.trig_number)
        self.push_change_event("mod",self.trig_number)
        

if __name__ == "__main__":
    sys.argv.append("TestDevice")

    run([TestDevice])